@@ -3,9 +3,9 @@ import numpy as np
 import statsmodels.api as sm
 from scipy import signal, integrate
 from pykalman import UnscentedKalmanFilter
-from fbprophet import prophet_dataframe
 from tsaug import magnify,affine, crop, cross_sum , resample, reverse, trend, random_affine, random_crop, random_cross_sum, random_sidetrack, random_time_warp, random_magnify, random_jitter, random_trend
-import prophet
+from fbprophet import Prophet
+
 
 
 def robust_scaler(df, drop=None,quantile_range=(25, 75) ):
